==> nhc98_1.16.orig.tar.gz: nhc98-1.16/src/prelude/Directory/DoesDirectoryExist.p.c <==
#include "newmacros.h"
#include "runtime.h"

#define FN_Directory_46hs_95doesDirectoryExist_35	((void*)startLabel+8)
#define CT_v184	((void*)startLabel+32)
#define F0_Directory_46hs_95doesDirectoryExist_35	((void*)startLabel+40)
#define FN_Directory_46hs_95doesDirectoryExist	((void*)startLabel+68)
#define CT_v188	((void*)startLabel+120)
#define CF_Directory_46hs_95doesDirectoryExist	((void*)startLabel+128)
#define CT_v193	((void*)startLabel+248)
#define ST_v190	((void*)startLabel+284)
#define PP_Directory_46hs_95doesDirectoryExist	((void*)startLabel+313)
#define PC_Directory_46hs_95doesDirectoryExist	((void*)startLabel+313)
#define ST_v186	((void*)startLabel+313)
#define PP_Directory_46hs_95doesDirectoryExist_35	((void*)startLabel+345)
#define PC_Directory_46hs_95doesDirectoryExist_35	((void*)startLabel+345)
#define ST_v183	((void*)startLabel+345)
#define PS_v187	((void*)startLabel+380)
#define PS_v185	((void*)startLabel+392)
#define PS_v191	((void*)startLabel+404)
#define PS_v192	((void*)startLabel+416)
#define PS_v189	((void*)startLabel+428)
#define PS_v182	((void*)startLabel+440)
void FR_Directory_46hs_95doesDirectoryExist_35(void);
extern Node FN_NHC_46Internal_46_95mkIOok1[];
extern Node FN_CString_46toCString[];
extern Node PM_Directory[];
extern Node PC_NHC_46Internal_46_95mkIOok1[];
extern Node PM_Directory[];
extern Node PM_Directory[];
extern Node PC_CString_46toCString[];
extern Node PM_Directory[];
extern Node PM_Directory[];
extern Node PM_Directory[];

static Node startLabel[] = {
  bytes2word(1,0,0,1)
, useLabel(CT_v184)
,	/* FN_Directory_46hs_95doesDirectoryExist_35: (byte 0) */
  bytes2word(PUSH_ARG_I1,EVAL,POP_I1,PRIMITIVE)
, useLabel(FR_Directory_46hs_95doesDirectoryExist_35)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 80022
, useLabel(ST_v183)
,	/* CT_v184: (byte 0) */
  HW(0,1)
, 0
,	/* F0_Directory_46hs_95doesDirectoryExist_35: (byte 0) */
  CAPTAG(useLabel(FN_Directory_46hs_95doesDirectoryExist_35),1)
, useLabel(PS_v182)
, 0
, 0
, 0
, bytes2word(0,0,0,0)
, useLabel(CT_v188)
,	/* FN_Directory_46hs_95doesDirectoryExist: (byte 0) */
  bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_P1,7)
, bytes2word(HEAP_CVAL_N1,7,HEAP_CREATE,HEAP_SPACE)
, bytes2word(HEAP_SPACE,HEAP_CVAL_P1,8,RETURN_EVAL)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 0
, useLabel(PS_v187)
, 0
, 0
, 0
, 0
, 80022
, useLabel(ST_v186)
,	/* CT_v188: (byte 0) */
  HW(2,0)
, 0
,	/* CF_Directory_46hs_95doesDirectoryExist: (byte 0) */
  VAPTAG(useLabel(FN_Directory_46hs_95doesDirectoryExist))
, useLabel(PS_v185)
, 0
, 0
, 0
, VAPTAG(useLabel(FN_NHC_46Internal_46_95mkIOok1))
, useLabel(F0_Directory_46hs_95doesDirectoryExist_35)
, bytes2word(1,0,0,1)
, useLabel(CT_v193)
,};
Node FN_Directory_46doesDirectoryExist[] = {
  bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_P1,7)
, bytes2word(HEAP_CVAL_N1,7,HEAP_CREATE,HEAP_SPACE)
, bytes2word(HEAP_SPACE,HEAP_ARG,1,PUSH_P1)
, bytes2word(0,PUSH_HEAP,HEAP_CVAL_P1,8)
, bytes2word(HEAP_CVAL_N1,12,HEAP_CREATE,HEAP_SPACE)
, bytes2word(HEAP_SPACE,ZAP_ARG_I1,ZAP_STACK_P1,2)
, bytes2word(EVAL,NEEDHEAP_I32,APPLY,1)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, useLabel(PS_v192)
, 0
, 0
, 0
, 0
, useLabel(PS_v191)
, 0
, 0
, 0
, 0
, 110001
, useLabel(ST_v190)
,	/* CT_v193: (byte 0) */
  HW(2,1)
, 0
,};
Node F0_Directory_46doesDirectoryExist[] = {
  CAPTAG(useLabel(FN_Directory_46doesDirectoryExist),1)
, useLabel(PS_v189)
, 0
, 0
, 0
, VAPTAG(useLabel(FN_CString_46toCString))
, VAPTAG(useLabel(FN_Directory_46hs_95doesDirectoryExist))
,};
Node PP_Directory_46doesDirectoryExist[] = {
 };
Node PC_Directory_46doesDirectoryExist[] = {
 	/* ST_v190: (byte 0) */
  bytes2word(68,105,114,101)
, bytes2word(99,116,111,114)
, bytes2word(121,46,100,111)
, bytes2word(101,115,68,105)
, bytes2word(114,101,99,116)
, bytes2word(111,114,121,69)
, bytes2word(120,105,115,116)
,	/* PP_Directory_46hs_95doesDirectoryExist: (byte 1) */
 	/* PC_Directory_46hs_95doesDirectoryExist: (byte 1) */
 	/* ST_v186: (byte 1) */
  bytes2word(0,68,105,114)
, bytes2word(101,99,116,111)
, bytes2word(114,121,46,104)
, bytes2word(115,95,100,111)
, bytes2word(101,115,68,105)
, bytes2word(114,101,99,116)
, bytes2word(111,114,121,69)
, bytes2word(120,105,115,116)
,	/* PP_Directory_46hs_95doesDirectoryExist_35: (byte 1) */
 	/* PC_Directory_46hs_95doesDirectoryExist_35: (byte 1) */
 	/* ST_v183: (byte 1) */
  bytes2word(0,68,105,114)
, bytes2word(101,99,116,111)
, bytes2word(114,121,46,104)
, bytes2word(115,95,100,111)
, bytes2word(101,115,68,105)
, bytes2word(114,101,99,116)
, bytes2word(111,114,121,69)
, bytes2word(120,105,115,116)
, bytes2word(35,0,0,0)
,	/* PS_v187: (byte 0) */
  useLabel(PM_Directory)
, useLabel(PP_Directory_46hs_95doesDirectoryExist)
, useLabel(PC_NHC_46Internal_46_95mkIOok1)
,	/* PS_v185: (byte 0) */
  useLabel(PM_Directory)
, useLabel(PP_Directory_46hs_95doesDirectoryExist)
, useLabel(PC_Directory_46hs_95doesDirectoryExist)
,	/* PS_v191: (byte 0) */
  useLabel(PM_Directory)
, useLabel(PP_Directory_46doesDirectoryExist)
, useLabel(PC_CString_46toCString)
,	/* PS_v192: (byte 0) */
  useLabel(PM_Directory)
, useLabel(PP_Directory_46doesDirectoryExist)
, useLabel(PC_Directory_46hs_95doesDirectoryExist)
,	/* PS_v189: (byte 0) */
  useLabel(PM_Directory)
, useLabel(PP_Directory_46doesDirectoryExist)
, useLabel(PC_Directory_46doesDirectoryExist)
,	/* PS_v182: (byte 0) */
  useLabel(PM_Directory)
, useLabel(PP_Directory_46hs_95doesDirectoryExist_35)
, useLabel(PC_Directory_46hs_95doesDirectoryExist_35)
,};

#include <haskell2c.h>
#include <HsFFI.h>

/* foreign import ccall "hs_doesDirectoryExist" Directory.hs_doesDirectoryExist# 1 :: PackedString.PackedString -> Prelude.Bool */
extern HsBool hs_doesDirectoryExist(char*);
#ifdef PROFILE
static SInfo pf_hs_doesDirectoryExist = {"Directory","Directory.hs_doesDirectoryExist#","Prelude.Bool"};
#endif
C_HEADER(FR_Directory_46hs_95doesDirectoryExist_35) {
  NodePtr nodeptr;
  HsBool result;
  char* arg1;
  nodeptr = C_GETARG1(1);
  IND_REMOVE(nodeptr);
  arg1 = (char*)nhc_getPackedString(nodeptr);

  result = hs_doesDirectoryExist(arg1);

  nodeptr = nhc_mkBool(result);
  INIT_PROFINFO(nodeptr,&pf_hs_doesDirectoryExist);
  C_RETURN(nodeptr);
}

==> nhc98_1.18.orig.tar.gz: nhc98-1.18/src/prelude/Directory/DoesDirectoryExist.p.c <==
#include "newmacros.h"
#include "runtime.h"

#define FN_Directory_46hs_95doesDirectoryExist_35	((void*)startLabel+8)
#define CT_v189	((void*)startLabel+32)
#define F0_Directory_46hs_95doesDirectoryExist_35	((void*)startLabel+40)
#define FN_Directory_46hs_95doesDirectoryExist	((void*)startLabel+68)
#define CT_v193	((void*)startLabel+120)
#define CF_Directory_46hs_95doesDirectoryExist	((void*)startLabel+128)
#define CT_v198	((void*)startLabel+248)
#define ST_v195	((void*)startLabel+284)
#define PP_Directory_46hs_95doesDirectoryExist	((void*)startLabel+313)
#define PC_Directory_46hs_95doesDirectoryExist	((void*)startLabel+313)
#define ST_v191	((void*)startLabel+313)
#define PP_Directory_46hs_95doesDirectoryExist_35	((void*)startLabel+345)
#define PC_Directory_46hs_95doesDirectoryExist_35	((void*)startLabel+345)
#define ST_v188	((void*)startLabel+345)
#define PS_v192	((void*)startLabel+380)
#define PS_v190	((void*)startLabel+392)
#define PS_v196	((void*)startLabel+404)
#define PS_v197	((void*)startLabel+416)
#define PS_v194	((void*)startLabel+428)
#define PS_v187	((void*)startLabel+440)
void FR_Directory_46hs_95doesDirectoryExist_35(void);
extern Node FN_NHC_46Internal_46_95mkIOok1[];
extern Node FN_CString_46toCString[];
extern Node PM_Directory[];
extern Node PC_NHC_46Internal_46_95mkIOok1[];
extern Node PC_CString_46toCString[];

static Node startLabel[] = {
  bytes2word(1,0,0,1)
, useLabel(CT_v189)
,	/* FN_Directory_46hs_95doesDirectoryExist_35: (byte 0) */
  bytes2word(PUSH_ARG_I1,EVAL,POP_I1,PRIMITIVE)
, useLabel(FR_Directory_46hs_95doesDirectoryExist_35)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 80001
, useLabel(ST_v188)
,	/* CT_v189: (byte 0) */
  HW(0,1)
, 0
,	/* F0_Directory_46hs_95doesDirectoryExist_35: (byte 0) */
  CAPTAG(useLabel(FN_Directory_46hs_95doesDirectoryExist_35),1)
, useLabel(PS_v187)
, 0
, 0
, 0
, bytes2word(0,0,0,0)
, useLabel(CT_v193)
,	/* FN_Directory_46hs_95doesDirectoryExist: (byte 0) */
  bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_P1,7)
, bytes2word(HEAP_CVAL_N1,7,HEAP_CREATE,HEAP_SPACE)
, bytes2word(HEAP_SPACE,HEAP_CVAL_P1,8,RETURN_EVAL)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 0
, useLabel(PS_v192)
, 0
, 0
, 0
, 0
, 80001
, useLabel(ST_v191)
,	/* CT_v193: (byte 0) */
  HW(2,0)
, 0
,	/* CF_Directory_46hs_95doesDirectoryExist: (byte 0) */
  VAPTAG(useLabel(FN_Directory_46hs_95doesDirectoryExist))
, useLabel(PS_v190)
, 0
, 0
, 0
, VAPTAG(useLabel(FN_NHC_46Internal_46_95mkIOok1))
, useLabel(F0_Directory_46hs_95doesDirectoryExist_35)
, bytes2word(1,0,0,1)
, useLabel(CT_v198)
,};
Node FN_Directory_46doesDirectoryExist[] = {
  bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_P1,7)
, bytes2word(HEAP_CVAL_N1,7,HEAP_CREATE,HEAP_SPACE)
, bytes2word(HEAP_SPACE,HEAP_ARG,1,PUSH_P1)
, bytes2word(0,PUSH_HEAP,HEAP_CVAL_P1,8)
, bytes2word(HEAP_CVAL_N1,12,HEAP_CREATE,HEAP_SPACE)
, bytes2word(HEAP_SPACE,ZAP_ARG_I1,ZAP_STACK_P1,2)
, bytes2word(EVAL,NEEDHEAP_I32,APPLY,1)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, useLabel(PS_v197)
, 0
, 0
, 0
, 0
, useLabel(PS_v196)
, 0
, 0
, 0
, 0
, 110001
, useLabel(ST_v195)
,	/* CT_v198: (byte 0) */
  HW(2,1)
, 0
,};
Node F0_Directory_46doesDirectoryExist[] = {
  CAPTAG(useLabel(FN_Directory_46doesDirectoryExist),1)
, useLabel(PS_v194)
, 0
, 0
, 0
, VAPTAG(useLabel(FN_CString_46toCString))
, VAPTAG(useLabel(FN_Directory_46hs_95doesDirectoryExist))
,};
Node PP_Directory_46doesDirectoryExist[] = {
 };
Node PC_Directory_46doesDirectoryExist[] = {
 	/* ST_v195: (byte 0) */
  bytes2word(68,105,114,101)
, bytes2word(99,116,111,114)
, bytes2word(121,46,100,111)
, bytes2word(101,115,68,105)
, bytes2word(114,101,99,116)
, bytes2word(111,114,121,69)
, bytes2word(120,105,115,116)
,	/* PP_Directory_46hs_95doesDirectoryExist: (byte 1) */
 	/* PC_Directory_46hs_95doesDirectoryExist: (byte 1) */
 	/* ST_v191: (byte 1) */
  bytes2word(0,68,105,114)
, bytes2word(101,99,116,111)
, bytes2word(114,121,46,104)
, bytes2word(115,95,100,111)
, bytes2word(101,115,68,105)
, bytes2word(114,101,99,116)
, bytes2word(111,114,121,69)
, bytes2word(120,105,115,116)
,	/* PP_Directory_46hs_95doesDirectoryExist_35: (byte 1) */
 	/* PC_Directory_46hs_95doesDirectoryExist_35: (byte 1) */
 	/* ST_v188: (byte 1) */
  bytes2word(0,68,105,114)
, bytes2word(101,99,116,111)
, bytes2word(114,121,46,104)
, bytes2word(115,95,100,111)
, bytes2word(101,115,68,105)
, bytes2word(114,101,99,116)
, bytes2word(111,114,121,69)
, bytes2word(120,105,115,116)
, bytes2word(35,0,0,0)
,	/* PS_v192: (byte 0) */
  useLabel(PM_Directory)
, useLabel(PP_Directory_46hs_95doesDirectoryExist)
, useLabel(PC_NHC_46Internal_46_95mkIOok1)
,	/* PS_v190: (byte 0) */
  useLabel(PM_Directory)
, useLabel(PP_Directory_46hs_95doesDirectoryExist)
, useLabel(PC_Directory_46hs_95doesDirectoryExist)
,	/* PS_v196: (byte 0) */
  useLabel(PM_Directory)
, useLabel(PP_Directory_46doesDirectoryExist)
, useLabel(PC_CString_46toCString)
,	/* PS_v197: (byte 0) */
  useLabel(PM_Directory)
, useLabel(PP_Directory_46doesDirectoryExist)
, useLabel(PC_Directory_46hs_95doesDirectoryExist)
,	/* PS_v194: (byte 0) */
  useLabel(PM_Directory)
, useLabel(PP_Directory_46doesDirectoryExist)
, useLabel(PC_Directory_46doesDirectoryExist)
,	/* PS_v187: (byte 0) */
  useLabel(PM_Directory)
, useLabel(PP_Directory_46hs_95doesDirectoryExist_35)
, useLabel(PC_Directory_46hs_95doesDirectoryExist_35)
,};

#include <haskell2c.h>
#include <HsFFI.h>

/* foreign import ccall "hs_doesDirectoryExist" Directory.hs_doesDirectoryExist# 1 :: PackedString.PackedString -> Prelude.Bool */
extern HsBool hs_doesDirectoryExist(char*);
#ifdef PROFILE
static SInfo pf_Directory_46hs_95doesDirectoryExist_35 = {"Directory","Directory.hs_doesDirectoryExist#","Prelude.Bool"};
#endif
C_HEADER(FR_Directory_46hs_95doesDirectoryExist_35) {
  NodePtr nodeptr;
  HsBool result;
  char* arg1;
  nodeptr = C_GETARG1(1);
  IND_REMOVE(nodeptr);
  arg1 = (char*)nhc_getPackedString(nodeptr);

  result = hs_doesDirectoryExist(arg1);

  nodeptr = nhc_mkBool(result);
  INIT_PROFINFO(nodeptr,&pf_Directory_46hs_95doesDirectoryExist_35);
  C_RETURN(nodeptr);
}
